*******************
:mod:`gdsCAD.utils`
*******************

.. automodule:: gdsCAD.utils


Function Summary
================
.. currentmodule:: gdsCAD.utils

Transformation Functions
------------------------
.. autosummary::
    translate
    rotate
    reflect
    scale

Layer Organization Functions
----------------------------
.. autosummary::
    split_layers
    relayer

Deprecated Functions
--------------------
These are old gdspy functions that no longer work, but may some day prove useful again

.. autosummary::
    chop
    slice
    boolean

Module Definitions
==================
.. automodule:: gdsCAD.utils
   :members:
   :undoc-members:
   :show-inheritance:
